<template>
    <div class="report-overview fullpage">
        <div class="title">
            <!-- <div class="title-name">区县改革报表指标体系及评价细则（4.0版）</div> -->
            <div class="title-name">{{ file.name }}</div>
            <el-button v-if="show" class="export-btn" size="small" type="primary" @click="frontDownload">下载</el-button>
        </div>
        <div class="docx-box" v-loading="!show" element-loading-background="rgba(1, 33, 90, 1)">
            <div style="width: 100%;" v-if="show">
                <Docx :fileUrl="file.url" :fileId="''"></Docx>
            </div>
        </div>
    </div>
</template>

<script>
import Docx from '@/components/docx'
export default {
    name: 'indexSystem',
    components: { Docx },
    data() {
        return {
            show: false,
            fileUrl: './files/docx/改革报表2024年指标体系.docx',
            fileData: [
                {
                    name: '区县改革报表指标体系及评价细则',
                    url: './files/docx/区县改革报表指标体系及评价细则（4.0）.docx',
                    quarter: ['2023Q0', '2023Q1', '2023Q2', '2023Q3', '2023Q4']
                },
                {
                    name: '2024版区县改革报表指标体系及评价细则',
                    url: './files/docx/改革报表2024年指标体系.docx',
                    quarter: ['2024Q1']
                },
                {
                    name: '202406版区县改革报表指标体系及评价细则',
                    url: './files/docx/202406版区县改革报表指标体系及评价细则.docx',
                    quarter: ['2024Q2','2024Q3']
                },
                {
                    name: '202412版报表细则',
                    url: './files/docx/202412版报表细则.docx',
                    quarter: ['2025Q1'],
                },
            ],
            file: {}
        }
    },
    mounted() {
        this.setFile()
        this.$bus.$on('changeDate', () => {
            this.setFile()
        })
    },
    methods: {
        setFile() {
            this.show = false
            setTimeout(() => {
                let { year, quarter } = JSON.parse(sessionStorage.getItem('searchDate'))
                let str = year + 'Q' + quarter
                let file = this.fileData.find(item => item.quarter.includes(str))
                this.file = file
                this.show = true
            }, 500)
        },
        frontDownload() {
            var a = document.createElement('a') // 创建一个<a></a>标签
            a.href = this.file.url
            a.download = this.file.name + '.docx' // 设置下载文件文件名
            a.style.display = 'none' // 隐藏a标签
            document.body.appendChild(a) // 将a标签追加到文档对象中
            a.click() // 模拟点击了a标签，会触发a标签的href的读取，浏览器就会自动下载了
            a.remove() // 一次性的，用完就删除a标签
        },
    },
}
</script>

<style lang="scss" scoped>
.report-overview.fullpage {
    position: relative;
    width: 100%;
    height: calc(100% - 30PX);

    .title {
        display: flex;
        justify-content: center;

        // align-items: center;
        .title-name {
            font-size: 24PX;
        }
    }

    .docx-box {
        margin: 5PX 10% 0 10%;
        width: 80%;
        height: calc(100% - 5px);
        overflow: auto;

        /* 设置滚动条的样式 */
        &::-webkit-scrollbar {
            width: 8px !important; //垂直方向上的宽
            height: 8px !important; //水平方向上的宽
        }

        /* 滚动槽 */
        &::-webkit-scrollbar-track {
            border-radius: 0;
            background-color: #01215a !important;
        }

        /* 滚动条滑块 */
        &::-webkit-scrollbar-thumb {
            border-radius: 18px;
            background-color: rgba(#fff, 0.1) !important;
        }

        /*滚动条交叉样式*/
        &::-webkit-scrollbar-corner {
            background: #01215a !important;
        }
    }

    .export-btn {
        position: absolute;
        right: 20%;
        top: -5PX;
        height: 30PX;
        line-height: 10PX;

        /deep/span {
            font-size: 14PX !important;
        }

    }

}
</style>
